FUNCTION Centroid, array
;
;+
;   Name: centroid
;
;   Purpose: calculate the centroid ("center of mass") of 2D array
;
;   Input Parameters:
;      array - 2D array
;
;   Output:
;      function returns centroid [xc,yc]
;
;   Calling Example:
;       center=centroid(array)
;
;   History:
;      S.L.Freeland - from Dave Fannings example
;                     http://www.dfanning.com/tip_examples/centroid.pro
;
;-
;


IF data_check(array,/ndim) NE 2 THEN BEGIN
   Message, 'Array must be two-dimensional. Returning...', /Informational
   RETURN, -1
ENDIF

totalMass = Total(array)

xcm = Total( Total(array, 2) * lindgen(data_chk(array,/nx)) ) / totalMass
ycm = Total( Total(array, 1) * lindgen(data_chk(array,/ny)) ) / totalMass

RETURN, [xcm, ycm]
END
